postgres-extras-clj.core

A toolbox for inspecting PostgreSQL databases in Clojure.

The SQL query logic is based entirely on the great work done by these three projects:

Queries ported to HugSQL syntax to access them as Clojure data structures.

See also sql/*.sql, where the query logic is defined.

A toolbox for inspecting PostgreSQL databases in Clojure.

The SQL query logic is based entirely on the great work done by these three projects:
  * https://github.com/heroku/heroku-pg-extras/tree/main
  * https://github.com/pawurb/ecto_psql_extras/tree/main
  * https://github.com/rustprooflabs/pgdd

Queries ported to HugSQL syntax to access them as Clojure data structures. 

See also `sql/*.sql`, where the query logic is defined.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries